translate.tools.porestructure

Package translate :: Package tools :: Module porestructure |
[hide private]
[frames] | no frames]

# Module porestructure

source code

Restructure Gettxt PO files produced by poconflicts into the original directory tree for merging using pomerge

See: http://translate.sourceforge.net/wiki/toolkit/porestructure for examples and usage instructions

Classes | [hide private]
| SplitOptionParser a specialized Option Parser for posplit

Functions | [hide private]
main() | source code

Imports: sys, os, po, optrecurse